==> sagua_0.1-1.tar.gz: sagua-0.1/include/mainmanager.h <==
#ifndef GUARD_mainmanager_h
#define GUARD_mainmanager_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <string>
#include <vector>
#include <map>

#include <glibmm.h>
#include <gtkmm/main.h>

#include "trayicon.h"
#include "audio.h"
#include "preference.h"
#include "mainwin.h"

class PrefWnd;

// class for main manager
// Almost class is connected to main manager, not to exact class.
class MainManager
{
    public:
	const unsigned int audioFormatLittleEndian_;
	const unsigned int audioFormatBigEndian_;
	const unsigned int audioFormatNativeEndian_;

	static MainManager* Create()
	{
	    static MainManager mainManager_;

	    return &mainManager_;
	}

	void Run()
	{
	    Gtk::Main::run();
	}


	const Preference& GetPreference()
	{
	    return preference_;
	}

	Preference& GetWritablePreference()
	{
	    return preference_;
	}


	const bool& HideMainWndOnIconify()
	{
	    return preference_.GeneralLeaveOnTrayWhenIconify();
	}

	
	void AudioSetDriver()
	{
	    if(mainWnd_.InPlay())
		mainWnd_.StopPlayForSetDriver();
	    else
		audio_->SetDriverFromPreference();
	}

	void AudioSetDriverFromPreference()
	{
	    audio_->SetDriverFromPreference();
	}

	bool AudioOpenDevice(const unsigned int& bits, const unsigned int& channels, const unsigned int& sampleRate, const unsigned int& endian)
	{
	    return audio_->OpenDevice(bits, channels, sampleRate, endian);
	}

	bool AudioCheckOpenDevice()
	{
	    return audio_->CheckOpenDevice();
	}

	void AudioClose()
	{
	    audio_->Close();
	}

	bool AudioTestDriver(const char* const driverName, const std::map<std::string, std::string>& options)
	{
	    return audio_->TestDriver(driverName, options);
	}

	int AudioPlay(const std::vector<double>& samples, const unsigned int& bytes)
	{
	    return audio_->Play(samples, bytes);
	}

	int AudioPlay(float** const samples, const unsigned int& bytes)
	{
	    return audio_->Play(samples, bytes);
	}


	void PlayCtrlPrev()
	{
	    mainWnd_.OnBtnPrev();
	}

	void PlayCtrlPlay()
	{
	    mainWnd_.OnBtnPlay();
	}

	void PlayCtrlStop()
	{
	    mainWnd_.OnBtnStop();
	}

	void PlayCtrlNext()
	{
	    mainWnd_.OnBtnNext();
	}


	void PlayFinish()
	{
	    mainWnd_.FinishPlay();
	}

	void PlayTimeUpdate()
	{
	    mainWnd_.TimeUpdate();
	}


	void FileInfo()
	{
	    mainWnd_.CurrentFileInfo();
	}


	void TrayIconSetTooltips(const Glib::ustring& string)
	{
	    trayIcon_.SetTooltips(string);
	}

	void TrayIconFirstBtnClickAction()
	{
	    CallbackMapCIter i = trayIconFirstBtnCallbacks_.find(preference_.GeneralTrayIconAction());

	    if(i != trayIconFirstBtnCallbacks_.end())
		(this->*(i->second))();

	}


	void MainWndIconifyEvent();
	void MainWndDeiconify();

	void About();

	void Quit();

    private:
	MainManager();
	~MainManager();
	MainManager(const MainManager&);
	MainManager& operator=(const MainManager&);

	TrayIcon trayIcon_;
	Preference preference_;
	std::auto_ptr<Audio> audio_;
	MainWnd mainWnd_;

	typedef std::map<std::string, void (MainManager::*)()> CallbackMap;
	typedef CallbackMap::const_iterator CallbackMapCIter;

	CallbackMap trayIconFirstBtnCallbacks_;

};

#endif

==> sagua_0.1.1-1.tar.gz: sagua-0.1.1/include/mainmanager.h <==
#ifndef GUARD_mainmanager_h
#define GUARD_mainmanager_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <string>
#include <vector>
#include <map>

#include <glibmm.h>
#include <gtkmm/main.h>

#include "trayicon.h"
#include "audio.h"
#include "preference.h"
#include "mixer.h"
#include "mainwin.h"

class PrefWnd;

// class for main manager
// Almost class is connected to main manager, not to exact class.
class MainManager
{
    public:
	const unsigned int audioFormatLittleEndian_;
	const unsigned int audioFormatBigEndian_;
	const unsigned int audioFormatNativeEndian_;

	static MainManager* Create()
	{
	    static MainManager mainManager_;

	    return &mainManager_;
	}

	void Run()
	{
	    Gtk::Main::run();
	}


	const Preference& GetPreference()
	{
	    return preference_;
	}

	Preference& GetWritablePreference()
	{
	    return preference_;
	}


	const bool& HideMainWndOnIconify()
	{
	    return preference_.GeneralLeaveOnTrayWhenIconify();
	}

	const std::string& MixerDev() const
	{
	    return preference_.MixerDev();
	}

	
	void AudioSetDriver()
	{
	    if(mainWnd_.InPlay())
		mainWnd_.StopPlayForSetDriver();
	    else
		audio_->SetDriverFromPreference();
	}

	void AudioSetDriverFromPreference()
	{
	    audio_->SetDriverFromPreference();
	}

	bool AudioOpenDevice(const unsigned int& bits, const unsigned int& channels, const unsigned int& sampleRate, const unsigned int& endian)
	{
	    return audio_->OpenDevice(bits, channels, sampleRate, endian);
	}

	bool AudioCheckOpenDevice()
	{
	    return audio_->CheckOpenDevice();
	}

	void AudioClose()
	{
	    audio_->Close();
	}

	bool AudioTestDriver(const char* const driverName)
	{
	    return audio_->TestDriver(driverName);
	}

	bool AudioTestDriver(const char* const driverName, const std::map<std::string, std::string>& options)
	{
	    return audio_->TestDriver(driverName, options);
	}

	void AudioPlay(const std::vector<double>& samples, const unsigned int& bytes)
	{
	    audio_->Play(samples, bytes);
	}

	void AudioPlay(float** const samples, const unsigned int& bytes)
	{
	    audio_->Play(samples, bytes);
	}

	void AudioPauseToggle()
	{
	    audio_->PauseToggle(false);
	}

	void AudioUnpause()
	{
	    if(audio_->Paused())
		audio_->PauseToggle(true);
	}

	
	void MixerRefresh()
	{
	    mainWnd_.RefreshMixer();
	}
	
	const double& MixerGetVolumn()
	{
	    return mixer_->GetVolumn();
	}

	void MixerSetVolumn(const double& volumn)
	{
	    mixer_->SetVolumn(volumn);
	}

	void MixerVolumnIncrease()
	{
	    mainWnd_.VolumnIncrease();
	}

	void MixerVolumnDecrease()
	{
	    mainWnd_.VolumnDecrease();
	}


	void PlayCtrlPrev()
	{
	    mainWnd_.OnBtnPrev();
	}

	void PlayCtrlPlay()
	{
	    mainWnd_.OnBtnPlay();
	}

	void PlayCtrlStop()
	{
	    mainWnd_.OnBtnStop();
	}

	void PlayCtrlNext()
	{
	    mainWnd_.OnBtnNext();
	}


	void PlayFinish()
	{
	    mainWnd_.FinishPlay();
	}

	void PlayTimeUpdate()
	{
	    mainWnd_.TimeUpdate();
	}


	void FileInfo()
	{
	    mainWnd_.CurrentFileInfo();
	}


	void TrayIconSetTooltips(const Glib::ustring& string)
	{
	    trayIcon_.SetTooltips(string);
	}

	void TrayIconFirstBtnClickAction()
	{
	    CallbackMapCIter i = trayIconFirstBtnCallbacks_.find(preference_.GeneralTrayIconAction());

	    if(i != trayIconFirstBtnCallbacks_.end())
		(this->*(i->second))();

	}


	void MainWndIconifyEvent();
	void MainWndDeiconify();

	void About();

	void Quit();

    private:
	MainManager();
	~MainManager();
	MainManager(const MainManager&);
	MainManager& operator=(const MainManager&);

	TrayIcon trayIcon_;
	Preference preference_;
	std::auto_ptr<Audio> audio_;
	Mixer* mixer_;
	MainWnd mainWnd_;

	typedef std::map<std::string, void (MainManager::*)()> CallbackMap;
	typedef CallbackMap::const_iterator CallbackMapCIter;

	CallbackMap trayIconFirstBtnCallbacks_;

};

#endif
